##  Mapping Subscriptions to Responsibilities
You can map subscription roles of the Responsible type from SAP LeanIX to responsibilities on the corresponding asset in Collibra. Once mapped, the subscriptions discovered on the fact sheets are synchronized on corresponding assets in Collibra.
In the Role Mapping field, choose subscription roles of the type Responsible and map them to corresponding roles in Collibra
You can also automatically create users who exist in SAP LeanIX but not in Collibra by selecting the Create Users check box.
**Caution**
Creating responsibilities for new or existing users may result in additional license costs for your Collibra usage, depending on the license requirement of the selected role. Review your license requirements for the roles in Collibra before proceeding.
